@@ -27,8 +27,9 @@
 #include "system.h"
 #include "voice.h"
 #include "chordorrest.h"
+#include "note.h"
 
-#define X_POS_PAGE_REL(p) ((getPage()->getContetXpos() + (p)) * zoom_factor - leftx)
+#define X_POS_PAGE_REL(p) ((getPage()->getContentXpos() + (p)) * zoom_factor - leftx)
 #define Y_POS_STAFF_REL(p) (((p) + getSystem()->getYPos() + getStaff()->getBottomPos()) * zoom_factor - topy)
 
 #define X_PS_POS(p) ((DEFAULT_BORDER + LEFT_RIGHT_BORDER + (p)) * PS_ZOOM)
@@ -85,21 +86,52 @@ int NedBeam::getChordCount() {
 bool NedBeam::isEqual(GList *beamlist, NedChordOrRest *except, int *diff_pos) {
 	return NedResource::equalContent(m_beamed_chords, beamlist, except, diff_pos);
 }
+
+bool NedBeam::isFirstInBeam(NedChordOrRest *chord) {
+	return (g_list_first(m_beamed_chords)->data == chord);
+}
+
+bool NedBeam::isLastInBeam(NedChordOrRest *chord) {
+	return (g_list_last(m_beamed_chords)->data == chord);
+}
+
+NedChordOrRest *NedBeam::getFirst() {
+	return (NedChordOrRest *) g_list_first(m_beamed_chords)->data;
+}
+
+NedChordOrRest *NedBeam::getLast() {
+	return (NedChordOrRest *) g_list_last(m_beamed_chords)->data;
+}
+
 	
 
-void NedBeam::computeBeam(int stem_dir /* = STEM_DIR_NONE */) {
+void NedBeam::computeBeam(int staff_voice_offs) {
 	GList *lptr;
 	int i;
+	int slope_idx = 0, slope_down_idx = 0;
 	double h, x;
 	double sumdist, dist;
-	double summ_mid_dist_down, summ_mid_dist_up, middist;
-	double endy_down, slope_down, starty_down, startx_down, endx_down, last_sum_dist_down = 100000.0;
+	double summ_mid_dist_down, summ_mid_dist_up = 0.0, middist;
+	double endy_down = 0.0, slope_down = 0.0, starty_down = 0.0, startx_down = 0.0, endx_down = 0.0, last_sum_dist_down = 100000.0;
 	double slope, starty, last_sum_dist = 100000.0;
+	bool user_stem = false;
+	bool predefined_up = false;
+	int stem_dir;
 
 
 	NedChordOrRest *first = (NedChordOrRest *) g_list_first(m_beamed_chords)->data;
 	NedChordOrRest *last = (NedChordOrRest *) g_list_last(m_beamed_chords)->data;
 
+	stem_dir = first->getStemDirectionOfTheMeasure(staff_voice_offs);
+
+	user_stem = ((first->getStatus() & STAT_USER_STEMDIR) != 0);
+	if (user_stem) {
+		predefined_up = ((first->getStatus() & STAT_UP) != 0);
+	}
+	if (first->getFirstNote()->getNoteHead() == GUITAR_NOTE_STEM) {
+			user_stem = true; predefined_up = false;
+	}
+
 	if (first->getType() == TYPE_GRACE) {
 		switch (first->getLength()) {
 			case GRACE_16: m_beam_count = 2; break;
@@ -112,89 +144,111 @@ void NedBeam::computeBeam(int stem_dir /* = STEM_DIR_NONE */) {
 	m_end_x = last->getBeamXPos() + STEM_THICK / 2.0;
 
 	m_up = TRUE;
-	for (i = 0; i < SLOPE_COUNT; i++) {
-		starty = ((NedChordOrRest *) g_list_first(m_beamed_chords)->data)->getStemTop();
-		slope = m_slopes[i];
-		for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
-			x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
-			h = ((NedChordOrRest *) lptr->data)->getStemTop();
-			if (h < starty - (x - m_start_x) * slope) {
-				starty -= (starty - (x - m_start_x) * slope) - h;
+	if (!user_stem || predefined_up) {
+		for (i = 0; i < SLOPE_COUNT; i++) {
+			starty = ((NedChordOrRest *) g_list_first(m_beamed_chords)->data)->getStemTop();
+			slope = m_slopes[i];
+			for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
+				x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
+				h = ((NedChordOrRest *) lptr->data)->getStemTop();
+				if (h < starty - (x - m_start_x) * slope) {
+					starty -= (starty - (x - m_start_x) * slope) - h;
+				}
 			}
-		}
-		sumdist = 0.0;
-		for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
-			x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
-			h = ((NedChordOrRest *) lptr->data)->getStemTop();
-			dist = h - (starty - (x - m_start_x) * slope);
-			if (dist < 0) dist = -dist;
+			sumdist = 0.0;
+			for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
+				x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
+				h = ((NedChordOrRest *) lptr->data)->getStemTop();
+				dist = h - (starty - (x - m_start_x) * slope);
+				if (dist < 0) dist = -dist;
 #define QUAD
 #ifdef QUAD
-			sumdist += dist * dist;
+				sumdist += dist * dist;
 #else
-			sumdist += dist;
+				sumdist += dist;
 #endif
-		}
-		if (last_sum_dist > sumdist) {
-			last_sum_dist = sumdist;
-			m_start_y = starty;
-			m_slope = slope;
-		}
-	}
-
-	m_end_y = m_start_y - (m_end_x - m_start_x) * m_slope;
-
-	for (i = 0; i < SLOPE_COUNT; i++) {
-		starty = ((NedChordOrRest *) g_list_first(m_beamed_chords)->data)->getStemBottom();
-		slope = m_slopes[i];
-		for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
-			x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
-			h = ((NedChordOrRest *) lptr->data)->getStemBottom();
-			if (h > starty - (x - m_start_x) * slope) {
-				starty += h - (starty - (x - m_start_x) * slope);
+			}
+			if (last_sum_dist > sumdist) {
+				last_sum_dist = sumdist;
+				m_start_y = starty;
+				m_slope = slope;
+				slope_idx = i;
 			}
 		}
-		sumdist = 0.0;
-		for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
-			x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
-			h = ((NedChordOrRest *) lptr->data)->getStemBottom();
-			dist = (starty - (x - m_start_x) * slope) - h;
-			if (dist < 0)  dist = -dist;
-#ifdef QUAD
-			sumdist += dist * dist;
-#else
-			sumdist += dist;
-#endif
-		}
-		if (last_sum_dist_down > sumdist) {
-			last_sum_dist_down = sumdist;
-			starty_down = starty;
-			slope_down = slope;
-		}
+		slope_idx += ((NedChordOrRest *) g_list_last(m_beamed_chords)->data)->getSlopeOffset();
+		if (slope_idx < 0) slope_idx = 0;
+		if (slope_idx >= SLOPE_COUNT) slope_idx = SLOPE_COUNT-1;
+		m_slope = m_slopes[slope_idx];
+	
+		m_end_y = m_start_y - (m_end_x - m_start_x) * m_slope;
 	}
 
-	summ_mid_dist_up = 0.0;
-	middist = m_start_y - (-2* LINE_DIST);
-	if (middist < 0.0) middist = -middist;
-	summ_mid_dist_up += middist;
+	if (!user_stem || !predefined_up) {
+		for (i = 0; i < SLOPE_COUNT; i++) {
+			starty = ((NedChordOrRest *) g_list_first(m_beamed_chords)->data)->getStemBottom();
+			slope = m_slopes[i];
+			for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
+				x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
+				h = ((NedChordOrRest *) lptr->data)->getStemBottom();
+				if (h > starty - (x - m_start_x) * slope) {
+					starty += h - (starty - (x - m_start_x) * slope);
+				}
+			}
+			sumdist = 0.0;
+			for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
+				x = ((NedChordOrRest *) lptr->data)->getBeamXPos();
+				h = ((NedChordOrRest *) lptr->data)->getStemBottom();
+				dist = (starty - (x - m_start_x) * slope) - h;
+				if (dist < 0)  dist = -dist;
+#ifdef QUAD
+				sumdist += dist * dist;
+#else
+				sumdist += dist;
+#endif
+			}
+			if (last_sum_dist_down > sumdist) {
+				last_sum_dist_down = sumdist;
+				starty_down = starty;
+				slope_down_idx = i;
+			}
+		}
+		slope_down_idx += last->getSlopeOffset();
+		if (slope_down_idx < 0) slope_down_idx = 0;
+		if (slope_down_idx >= SLOPE_COUNT) slope_down_idx = SLOPE_COUNT-1;
+		slope_down = m_slopes[slope_down_idx];
+	}
 
-	middist = m_end_y - (-2* LINE_DIST);
-	if (middist < 0.0) middist = -middist;
-	summ_mid_dist_up += middist;
+	if (!user_stem || predefined_up) {
 
-	startx_down = first->getBeamXPos();
-	endx_down = last->getBeamXPos();
+		summ_mid_dist_up = 0.0;
+		middist = m_start_y - (-2* LINE_DIST);
+		if (middist < 0.0) middist = -middist;
+		summ_mid_dist_up += middist;
 
-	endy_down = starty_down - (endx_down - startx_down) * slope_down;
+		middist = m_end_y - (-2* LINE_DIST);
+		if (middist < 0.0) middist = -middist;
+		summ_mid_dist_up += middist;
+	}
+	if (!user_stem || !predefined_up) {
+		startx_down = first->getBeamXPos();
+		endx_down = last->getBeamXPos();
 
-	summ_mid_dist_down = 0.0;
-	middist = starty_down - (-2* LINE_DIST);
-	if (middist < 0.0) middist = -middist;
-	summ_mid_dist_down += middist;
+		endy_down = starty_down - (endx_down - startx_down) * slope_down;
 
-	middist = endy_down - (-2* LINE_DIST);
-	if (middist < 0.0) middist = -middist;
-	summ_mid_dist_down += middist;
+		summ_mid_dist_down = 0.0;
+		middist = starty_down - (-2* LINE_DIST);
+		if (middist < 0.0) middist = -middist;
+		summ_mid_dist_down += middist;
+	
+		middist = endy_down - (-2* LINE_DIST);
+		if (middist < 0.0) middist = -middist;
+		summ_mid_dist_down += middist;
+	}
+
+	if (user_stem) {
+		stem_dir = predefined_up ? STEM_DIR_UP : STEM_DIR_DOWN;
+	}
+		
 
 	if ((stem_dir == STEM_DIR_NONE && summ_mid_dist_down < summ_mid_dist_up) || stem_dir == STEM_DIR_DOWN) {
 		m_up = FALSE;
@@ -204,6 +258,8 @@ void NedBeam::computeBeam(int stem_dir /* = STEM_DIR_NONE */) {
 		m_start_x = startx_down;
 		m_end_x = endx_down;
 	}
+	m_start_y += first->getBeamOffset();
+	m_end_y += first->getBeamOffset();
 	for (lptr = g_list_first(m_beamed_chords); lptr; lptr = g_list_next(lptr)) {
 		((NedChordOrRest *) lptr->data)->xPositNotes();
 		((NedChordOrRest *) lptr->data)->computeBbox();
@@ -212,6 +268,10 @@ void NedBeam::computeBeam(int stem_dir /* = STEM_DIR_NONE */) {
 	m_tuplet_y = m_start_y + (m_end_y - m_start_y) / 2.0;
 }
 
+double NedBeam::getBeamLength() {
+	return m_end_x - m_start_x;
+}
+
 double NedBeam::getTopOfBeam() {
 	return m_start_y < m_end_y ? m_start_y : m_end_y;
 }
@@ -327,12 +387,13 @@ void NedBeam::draw(cairo_t *cr) {
 	double topy = getMainWindow()->getTopY();
 	double zoom_factor = getMainWindow()->getCurrentZoomFactor();
 	double leftx = getMainWindow()->getLeftX();
-	GList *lptr1, *lptr2, *last;
-	NedChordOrRest *chord1, *chord2, *lastchord;
+	GList *lptr1, *lptr2, *lptr0 = NULL, *last;
+	NedChordOrRest *chord0= NULL, *chord1, *chord2, *lastchord;
 	double xpos1, xpos2, ypos1, ypos2;
 	double mid_xpos, mid_ypos;
 	double lastxpos, lastypos;
 	int tval;
+	bool draw_half;
 	cairo_glyph_t glyph;
 
 
@@ -350,36 +411,55 @@ void NedBeam::draw(cairo_t *cr) {
 	lastypos = m_start_y - (lastxpos - m_start_x) * m_slope;
 	cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1));
 	cairo_line_to(cr, X_POS_PAGE_REL(lastxpos), Y_POS_STAFF_REL(lastypos));
-	for (lptr2 = g_list_next(lptr1); lptr2; lptr1 = lptr2, lptr2 = g_list_next(lptr2), chord1 = chord2, xpos1 = xpos2, ypos1 = ypos2) {
+	for (lptr2 = g_list_next(lptr1); lptr2; lptr0 = lptr1, lptr1 = lptr2, lptr2 = g_list_next(lptr2), chord0 = chord1, chord1 = chord2, xpos1 = xpos2, ypos1 = ypos2) {
 		chord2 = (NedChordOrRest *) lptr2->data;
 		xpos2 = m_up ? chord2->getBeamXPos() : chord2->getBeamXPos();
 		ypos2 = m_start_y - (xpos2 - m_start_x) * m_slope;
 		mid_xpos = xpos1 + (xpos2 - xpos1) / 2.0;
 		mid_ypos = ypos1 + (ypos2 - ypos1) / 2.0;
-		switch (chord1->getLength()) {
-		  case NOTE_64:
+		/*
+		printf("chord0: %u, chord1: %u, chord2: %u\n", lptr0 ? chord0->getLength() / NOTE_32: 1111111,
+			chord1->getLength() / NOTE_32, chord2->getLength() / NOTE_32); fflush(stdout);
+			*/
+
+		draw_half = (lptr0 == NULL || chord0->getLength() != chord1->getLength());
+		//if (lptr0 == NULL || chord0->getLength() != chord1->getLength() || chord1->getLength() >= chord2->getLength()) {
+		  switch (chord1->getLength()) {
+		    case NOTE_64:
 			cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 3 * dir * FLAG_DIST));
 			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST));
-		  case NOTE_32:
-			cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 2 * dir * FLAG_DIST));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST));
-		  case NOTE_16:
-			cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + dir * FLAG_DIST));
-			cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST));
-		}
-		if (lptr2 == last || chord2->getLength() >= chord1->getLength()) {
+		    case NOTE_32:
+		    	if (draw_half || chord2->getLength() <= NOTE_32) {
+				cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + 2 * dir * FLAG_DIST));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST));
+			}
+		    case NOTE_16:
+		    	if (draw_half || chord2->getLength() <= NOTE_16) {
+				cairo_move_to(cr, X_POS_PAGE_REL(xpos1), Y_POS_STAFF_REL(ypos1 + dir * FLAG_DIST));
+				cairo_line_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST));
+			}
+		  }
+		//}
+		draw_half = (lptr2 == last);
+		//if (lptr2 == last || chord2->getLength() >= chord1->getLength()) {
 		   switch (chord2->getLength()) {
 		     case NOTE_64:
-			cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 3 * dir * FLAG_DIST));
+		     	if (draw_half || chord1->getLength() <= NOTE_64) {
+				cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 3 * dir * FLAG_DIST));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 3 * dir * FLAG_DIST));
+			}
 		     case NOTE_32:
-			cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 2 * dir * FLAG_DIST));
+		     	if (draw_half || chord1->getLength() <= NOTE_32) {
+				cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + 2 * dir * FLAG_DIST));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + 2 * dir * FLAG_DIST));
+			}
 		     case NOTE_16:
-			cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST));
-			cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + dir * FLAG_DIST));
+		     	if (draw_half || chord1->getLength() <= NOTE_16) {
+				cairo_move_to(cr, X_POS_PAGE_REL(mid_xpos), Y_POS_STAFF_REL(mid_ypos + dir * FLAG_DIST));
+				cairo_line_to(cr, X_POS_PAGE_REL(xpos2), Y_POS_STAFF_REL(ypos2 + dir * FLAG_DIST));
+			}
 		   }
-		}
+		//}
 	}
 	cairo_stroke(cr);
 	cairo_new_path(cr);
