@@ -151,7 +151,7 @@ class NedChordOrRest {
 		void setHidden() {m_is_hidden = true;}
 		void setTime(unsigned int time)  {m_time = time;}
 		unsigned int getStatus() {return m_status;}
-		void setStatus(unsigned int status) {m_status = status;}
+		void setStatus(unsigned int status);
 		unsigned int getLength() {return m_length;}
 		void setLength(int length);
 		bool trySelect (double x, double y, bool only_free_placeables);
