@@ -81,11 +81,11 @@ void NedClipBoard::execute(bool adjust) {
 	if (adjust) {
 		if (voice_from != NULL) {
 			voice_from->getMainWindow()->reposit(NULL, voice_from->getPage(),
-				voice_from->getSystem(), false);
+				voice_from->getSystem());
 		}
 		if (voice_to != NULL) {
 			voice_to->getMainWindow()->reposit(NULL, voice_to->getPage(),
-			voice_to->getSystem(), false);
+			voice_to->getSystem());
 		}
 	}
 }
@@ -118,11 +118,11 @@ void NedClipBoard::unexecute(bool adjust) {
 	if (adjust) {
 		if (voice_from != NULL) {
 			voice_from->getMainWindow()->reposit(NULL, voice_from->getPage(),
-			voice_from->getSystem(), false);
+			voice_from->getSystem());
 		}
 		if (voice_to != NULL) {
 			voice_to->getMainWindow()->reposit(NULL, voice_to->getPage(),
-			voice_to->getSystem(), false);
+			voice_to->getSystem());
 		}
 	}
 }
@@ -165,11 +165,11 @@ void NedClipBoard::execute_reverse(bool adjust) {
 	if (adjust) {
 		if (voice_from != NULL) {
 			voice_from->getMainWindow()->reposit(NULL, voice_from->getPage(),
-			voice_from->getSystem(), false);
+			voice_from->getSystem());
 		}
 		if (voice_to != NULL) {
 			voice_to->getMainWindow()->reposit(NULL, voice_to->getPage(),
-			voice_to->getSystem(), false);
+			voice_to->getSystem());
 		}
 	}
 }
@@ -202,11 +202,11 @@ void NedClipBoard::unexecute_reverse(bool adjust) {
 	if (adjust) {
 		if (voice_from != NULL) {
 			voice_from->getMainWindow()->reposit(NULL, voice_from->getPage(),
-			voice_from->getSystem(), false);
+			voice_from->getSystem());
 		}
 		if (voice_to) {
 			voice_to->getMainWindow()->reposit(NULL, voice_to->getPage(),
-			voice_to->getSystem(), false);
+			voice_to->getSystem());
 		}
 	}
 }
