@@ -30,11 +30,11 @@
 
 
 #define MIN_MEASRURE_TYPE 0
-#define MAX_MEASURE_TYPE REPEAT_OPEN_CLOSE
+#define MAX_MEASURE_TYPE END_BAR
 
 
-NedMeasureConfigDialog::NedMeasureConfigDialog(GtkWindow *parent, int measure_type, bool alter1, bool alter2, bool allow_alter, int num, int denom) :
-m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_allow_alter(allow_alter), m_delete_timesig(false)  {
+NedMeasureConfigDialog::NedMeasureConfigDialog(GtkWindow *parent, int measure_type, bool alter1, bool alter2, bool allow_alter, bool hide_following, int num, int denom) :
+m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_hide_following(hide_following), m_allow_alter(allow_alter), m_delete_timesig(false)  {
 	GtkWidget *dialog;
 	GtkWidget *hbox;
 	GtkWidget *measure_type_frame;
@@ -54,6 +54,7 @@ m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_allo
 		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT, GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT, NULL);
 
 	g_signal_connect(dialog, "response", G_CALLBACK (OnClose), (void *) this);
+	m_original_type = (measure_type & REP_TYPE_MASK);
 
 
 	hbox = gtk_hbox_new(FALSE, 5);
@@ -95,6 +96,11 @@ m_measure_type(measure_type & REP_TYPE_MASK), m_num(num), m_denom(denom), m_allo
 	gtk_box_pack_start(GTK_BOX(alter_box), m_alter1_check_box, TRUE, TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(alter_box), m_alter2_check_box, TRUE, TRUE, 0);
 
+	m_hide_box = gtk_check_button_new_with_label(_("hide following"));
+	gtk_widget_set_sensitive(m_hide_box, (measure_type & REP_TYPE_MASK) == END_BAR || (measure_type & REP_TYPE_MASK) == REPEAT_CLOSE);
+	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(m_hide_box), m_hide_following);
+	gtk_box_pack_start(GTK_BOX(alter_box), m_hide_box, TRUE, TRUE, 0);
+
 	measure_type_vbox = gtk_vbox_new(FALSE, 2);
 	gtk_container_add (GTK_CONTAINER(measure_type_vbox), measure_type_hbox);
 	gtk_container_add (GTK_CONTAINER(measure_type_vbox), alter_box);
@@ -154,6 +160,7 @@ void NedMeasureConfigDialog::OnClose(GtkDialog *dialog, gint result, gpointer da
 	NedMeasureConfigDialog *measure_type_dialog = (NedMeasureConfigDialog *) data;
 	measure_type_dialog->m_alter1 = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_alter1_check_box));
 	measure_type_dialog->m_alter2 = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_alter2_check_box));
+	measure_type_dialog->m_hide_following = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(measure_type_dialog->m_hide_box));
 	switch (result) {
 		case GTK_RESPONSE_ACCEPT:
 			measure_type_dialog->m_state = TRUE;
@@ -195,11 +202,12 @@ void NedMeasureConfigDialog::delete_time_sig_checked (GtkToggleButton *togglebut
 	the_dialog->m_delete_timesig = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(the_dialog->m_delete_timsig_check_box));
 }
 
-void NedMeasureConfigDialog::getValues(bool *state, int *measure_type, bool *alter1, bool *alter2, bool *timsig_state, bool *delete_timesig, int *num, int *denom) {
+void NedMeasureConfigDialog::getValues(bool *state, int *measure_type, bool *alter1, bool *alter2, bool *hide_following, bool *timsig_state, bool *delete_timesig, int *num, int *denom) {
 	*state = m_state;
 	*measure_type = m_measure_type;
 	*alter1 = m_alter1 && m_measure_type == 2;
 	*alter2 = m_alter2 && m_measure_type == 2;
+	*hide_following = m_hide_following;
 	*num = m_num;
 	*denom = m_denom;
 	*timsig_state = m_timesig_state;
@@ -238,13 +246,13 @@ gboolean NedMeasureConfigDialog::draw_measure_types(GtkWidget *widget, GdkEventE
 				  break;
 		case REPEAT_CLOSE: cairo_new_path(cr);
 				  cairo_set_line_width(cr, ZOOM_FACTOR * REPEAT_MEASURE_LINE_THICK);
-				  cairo_move_to(cr, LINE_XPOS - REP_THICK_LINE_DIST * ZOOM_FACTOR, MINY);
-				  cairo_line_to(cr, LINE_XPOS - REP_THICK_LINE_DIST * ZOOM_FACTOR, MAXY);
+				  cairo_move_to(cr, LINE_XPOS + REP_THICK_LINE_DIST * ZOOM_FACTOR, MINY);
+				  cairo_line_to(cr, LINE_XPOS + REP_THICK_LINE_DIST * ZOOM_FACTOR, MAXY);
 				  cairo_stroke(cr);
 				  cairo_new_path(cr);
-				  cairo_arc(cr, LINE_XPOS - (REP_THICK_LINE_DIST + REP_DOTS_X_DIST) * ZOOM_FACTOR, MINY + REP_DOTS_Y1DIST * ZOOM_FACTOR,
+				  cairo_arc(cr, LINE_XPOS - REP_DOTS_X_DIST * 0.8 * ZOOM_FACTOR, MINY + REP_DOTS_Y1DIST * ZOOM_FACTOR,
 				  		REP_DOTS_RADIUS * ZOOM_FACTOR, 0.0, 2.0 * M_PI);
-				  cairo_arc(cr, LINE_XPOS - (REP_THICK_LINE_DIST + REP_DOTS_X_DIST) * ZOOM_FACTOR, MINY + REP_DOTS_Y2DIST * ZOOM_FACTOR,
+				  cairo_arc(cr, LINE_XPOS - REP_DOTS_X_DIST * 0.8 * ZOOM_FACTOR, MINY + REP_DOTS_Y2DIST * ZOOM_FACTOR,
 				  		REP_DOTS_RADIUS * ZOOM_FACTOR, 0.0, 2.0 * M_PI);
 				  cairo_fill(cr);
 				  break;
@@ -274,6 +282,18 @@ gboolean NedMeasureConfigDialog::draw_measure_types(GtkWidget *widget, GdkEventE
 				  		REP_DOTS_RADIUS * ZOOM_FACTOR, 0.0, 2.0 * M_PI);
 				cairo_fill(cr);
 				break;
+		case END_BAR:   cairo_new_path(cr);
+				cairo_set_line_width(cr, ZOOM_FACTOR * REPEAT_MEASURE_LINE_THICK);
+				cairo_move_to(cr, LINE_XPOS + REP_THICK_LINE_DIST * ZOOM_FACTOR, MINY);
+				cairo_line_to(cr, LINE_XPOS + REP_THICK_LINE_DIST * ZOOM_FACTOR, MAXY);
+				cairo_stroke(cr);
+				break;
+		case DOUBLE_BAR:cairo_new_path(cr);
+				cairo_set_line_width(cr, ZOOM_FACTOR * MEASURE_LINE_THICK);
+				cairo_move_to(cr, LINE_XPOS - REP_DOUBLE_LINE_DIST * ZOOM_FACTOR, MINY);
+				cairo_line_to(cr, LINE_XPOS - REP_DOUBLE_LINE_DIST * ZOOM_FACTOR, MAXY);
+				cairo_stroke(cr);
+				break;
 	}
 	if (the_dialog->m_measure_type != REPEAT_OPEN_CLOSE) {
 		cairo_new_path(cr);
@@ -312,6 +332,23 @@ void NedMeasureConfigDialog::previous_measure_type (GtkButton *button, gpointer
 		gtk_widget_set_sensitive(the_dialog->m_alter1_check_box, FALSE);
 		gtk_widget_set_sensitive(the_dialog->m_alter2_check_box, FALSE);
 	}
+	if ((the_dialog->m_measure_type & REP_TYPE_MASK) == END_BAR || (the_dialog->m_measure_type & REP_TYPE_MASK) == REPEAT_CLOSE) {
+		gtk_widget_set_sensitive(the_dialog->m_hide_box, TRUE);
+		if ((the_dialog->m_measure_type & REP_TYPE_MASK) != the_dialog->m_original_type) {
+			if ((the_dialog->m_measure_type & REP_TYPE_MASK) == END_BAR) {
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), TRUE);
+			}
+			else {
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), FALSE);
+			}
+		}
+		else {
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), the_dialog->m_hide_following);
+		}
+	}
+	else {
+		gtk_widget_set_sensitive(the_dialog->m_hide_box, FALSE);
+	}
 	rect.x = rect.y = 0;
 	rect.width = the_dialog->m_measure_type_show_window->allocation.width;
 	rect.height = the_dialog->m_measure_type_show_window->allocation.height;
@@ -338,6 +375,23 @@ void NedMeasureConfigDialog::next_measure_type (GtkButton *button, gpointer data
 		gtk_widget_set_sensitive(the_dialog->m_alter1_check_box, FALSE);
 		gtk_widget_set_sensitive(the_dialog->m_alter2_check_box, FALSE);
 	}
+	if ((the_dialog->m_measure_type & REP_TYPE_MASK) == END_BAR || (the_dialog->m_measure_type & REP_TYPE_MASK) == REPEAT_CLOSE) {
+		gtk_widget_set_sensitive(the_dialog->m_hide_box, TRUE);
+		if ((the_dialog->m_measure_type & REP_TYPE_MASK) != the_dialog->m_original_type) {
+			if ((the_dialog->m_measure_type & REP_TYPE_MASK) == END_BAR) {
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), TRUE);
+			}
+			else {
+				gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), FALSE);
+			}
+		}
+		else {
+			gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(the_dialog->m_hide_box), the_dialog->m_hide_following);
+		}
+	}
+	else {
+		gtk_widget_set_sensitive(the_dialog->m_hide_box, FALSE);
+	}
 	rect.x = rect.y = 0;
 	rect.width = the_dialog->m_measure_type_show_window->allocation.width;
 	rect.height = the_dialog->m_measure_type_show_window->allocation.height;
