@@ -149,14 +149,10 @@ class NedMainWindow {
 		double getCurrentZoomFactor() {return m_current_zoom;}
 		int getCurrentZoomLevel() {return m_current_zoom_level;}
 		double getCurrentScale() {return (double) m_current_scale / (double) SCALE_GRANULARITY;}
-		unsigned int getCurrentLength();
-		int getCurrentNoteHead();
-		unsigned int getStatus();
 		unsigned int getMainWindowStatus();
 		bool getShowHidden();
-		bool getRestMode();
+		bool hasFocus();
 		int getLyricsMode();
-		int getDotCount();
 		NedCommandHistory *getCommandHistory() {return m_command_history;}
 		double getLeftX();
 		double getTopY();
@@ -187,6 +183,12 @@ class NedMainWindow {
 		bool isTimsigChangingMeasure(int meas_num);
 		unsigned int getMeasureDuration(int meas_num);
 		bool findTimeOfMeasure(int meas_num, unsigned long long *meas_time);
+		void changeLength();
+		void changeState();
+		void changeDots();
+		void changeNoteHead();
+		void changeTieState();
+		void changeNoteState();
 		int getNumerator(int meas_num);
 		int getDenominator(int meas_num);
 		int getPreStaffCount() {return m_pre_staffcount;}
@@ -268,7 +270,6 @@ class NedMainWindow {
 		void disconnectKeys();
 		NedChordOrRest *findAndBeamElementsOfCurrentVoice();
 		void zoomFreeReplaceables(double zoom, double scale);
-		bool getTiedMode();
 		void resetSomeButtons();
 		void resetLyricsMode();
 		void moveSpecMeasure(SpecialMeasure *spec, int dir);
@@ -314,42 +315,20 @@ class NedMainWindow {
 		unsigned int m_upbeat_inverse;
 
 		GtkUIManager *m_ui_manager;
-		GtkWidget *m_gracebar;
-		GtkWidget *m_drumbar;
-		GtkWidget *m_more_acc_bar;
 		GtkWidget *m_customize_beam_button;
 		GtkAction *m_undo_action, *m_redo_action;
-		GtkToggleAction *m_sharp_action, *m_flat_action, *m_natural_action, *m_insert_erease_mode_action;
-		GtkToggleAction *m_stacc_action, *m_staccatissimo_action;
-		GtkToggleAction *m_tenuto_action;
-		GtkToggleAction *m_sforzato_action;
-		GtkToggleAction *m_sforzando_action;
-		GtkToggleAction *m_bow_up_action;
-		GtkToggleAction *m_bow_down_action;
-		GtkToggleAction *m_ped_on_action;
-		GtkToggleAction *m_ped_off_action;
-		GtkToggleAction *m_trill_action, *m_prall_action, *m_open_action, *m_mordent_action;
-		GtkToggleAction *m_arpeggio_action, *m_fermata_action;
-		GtkToggleAction *m_dsharp_action, *m_dflat_action;
+		GtkToggleAction *m_insert_erease_mode_action;
 		GtkToggleAction *m_shift_action, *m_keyboard_insert_action;
-		GtkToggleAction *m_pause_action, *m_dotted_action, *m_ddotted_action;
 		GtkToggleAction *m_show_hidden_action;
-		GtkToggleAction *m_tie_action;
 		GtkToggleAction *m_replay_action;
 		GtkToggleAction *m_show_measure_numbers_action;
 		GtkActionGroup *m_menu_action_group;
 		GtkActionGroup *m_open_recent_action_group;
-		GtkActionGroup *m_note_head_action_group;
-		GtkActionGroup *m_grace_action_group;
-		GtkActionGroup *m_more_acc_action_group;
 		GSList *m_voice_buttons;
-		GSList *m_note_length_buttons;
-		GSList *m_note_head_buttons;
 		GtkAction *m_recent_actions[MAX_RECENT_FILES];
 		GtkAction *m_remove_page_action;
 		GtkWidget *m_v1bu, *m_v2bu, *m_v3bu, *m_v4bu;
 		GtkWidget *m_main_vbox;
-		GtkWidget *m_extra_bar_hbox;
 
 		void draw (cairo_t *cr, int width, int height);
 		void setTopLeft(double x, double y);
@@ -361,14 +340,9 @@ class NedMainWindow {
 		char m_current_filename[4096];
 
 		static const GtkActionEntry main_tools[];
-		static const GtkRadioActionEntry note_actions[];
-		static const GtkToggleActionEntry toggle_buttons[];
 		static const GtkToggleActionEntry accessory_buttons[];
 		static const GtkToggleActionEntry toggle_mode_buttons[];
 		static const GtkToggleActionEntry insert_erease_button[];
-		static const GtkRadioActionEntry grace_actions[];
-		static const GtkToggleActionEntry more_acc_buttons[];
-		static const GtkRadioActionEntry note_head_actions[];
 		static const GtkActionEntry file_entries[];
 		static const char *guiDescription;
 		static gboolean handle_expose (GtkWidget *widget,
@@ -389,6 +363,7 @@ class NedMainWindow {
 		static void print_file(GtkWidget *widget, void *data);
 		static void import_musicxml(GtkWidget *widget, void *data);
 		static void import_midi(GtkWidget *widget, void *data);
+		static void import_midi2(GtkWidget *widget, void *data);
 		static void export_midi(GtkWidget *widget, void *data);
 		static void export_lily(GtkWidget *widget, void *data);
 		static void insert_tuplet(GtkWidget *widget, void *data);
@@ -430,7 +405,7 @@ class NedMainWindow {
 		static void remove_empty_pages(GtkWidget *widget, void *data);
 		static void change_spacement(GtkWidget *widget, void *data);
 		static void change_scale(GtkWidget *widget, void *data);
-		static void popup_test_menu(GtkWidget *widget, void *data);
+		static void popup_tools(GtkWidget *widget, void *data);
 		static void set_upbeat_measure(GtkWidget *widget, void *data);
 		static void set_upbeat_start(GtkWidget *widget, void *data);
 		static void edit_score_info(GtkWidget *widget, void *data);
@@ -460,43 +435,13 @@ class NedMainWindow {
 		static void empty_block(GtkWidget *widget, void *data);
 		static void toggle_insert_erease_mode(GtkAction *action, gpointer data);
 		static void prepare_keyboard_insertion(GtkAction *action, gpointer data);
-		static void set_rest_note_mode(GtkAction *action, gpointer data);
-		static void set_dotted_mode(GtkAction *action, gpointer data);
-		static void set_ddotted_mode(GtkAction *action, gpointer data);
-		static void set_dcross_mode(GtkAction *action, gpointer data);
-		static void set_dflat_mode(GtkAction *action, gpointer data);
-		static void set_staccato_mode(GtkAction *action, gpointer data);
-		static void set_staccatissimo_mode(GtkAction *action, gpointer data);
-//		static void set_str_pizz_mode(GtkAction *action, gpointer data);
-		static void set_tenuto_mode(GtkAction *action, gpointer data);
-		static void set_sforzato_mode(GtkAction *action, gpointer data);
-		static void set_sforzando_mode(GtkAction *action, gpointer data);
-		static void set_bow_up_mode(GtkAction *action, gpointer data);
-		static void set_bow_down_mode(GtkAction *action, gpointer data);
-		static void set_pedal_on_mode(GtkAction *action, gpointer data);
-		static void set_pedal_off_mode(GtkAction *action, gpointer data);
-		static void set_trill_mode(GtkAction *action, gpointer data);
-		static void set_prall_mode(GtkAction *action, gpointer data);
-		static void set_open_mode(GtkAction *action, gpointer data);
-		static void set_mordent_mode(GtkAction *action, gpointer data);
-		static void set_fermata_mode(GtkAction *action, gpointer data);
-		static void set_arpeggio_mode(GtkAction *action, gpointer data);
 		static void customize_beam(GtkAction *action, gpointer data);
 		static void flip_stem(GtkAction *action, gpointer data);
-		static void set_tied_mode(GtkAction *action, gpointer data);
 		static void do_play(GtkAction *action, gpointer data);
 		static void initiate_repaint(GtkAction *action, gpointer data);
 		static void set_paint_colored(GtkAction *action, gpointer data);
 		static void toggle_shift_mode(GtkAction *action, gpointer data);
-		static void set_sharp_mode(GtkAction *action, gpointer data);
-		static void set_flat_mode(GtkAction *action, gpointer data);
-		static void set_natural_mode(GtkAction *action, gpointer data);
-		static void show_graces(GtkAction *action, gpointer data);
-		static void show_drum_bar(GtkAction *action, gpointer data);
-		static void show_more_accs_bar(GtkAction *action, gpointer data);
 		static void toggle_show_hidden(GtkAction *action, gpointer data);
-		static void set_note_length(GtkAction *action, GtkRadioAction *current, void *data);
-		static void set_drum_note(GtkAction *action, GtkRadioAction *current, void *data);
 		static void size_change_handler(GtkWidget *widget, GtkRequisition *requisition, gpointer data);
 		static gboolean handle_delete(GtkWidget *widget, GdkEvent *event, gpointer data);
 		static void handle_page_request(GtkSpinButton *spinbutton, gpointer data);
@@ -571,6 +516,7 @@ class NedMainWindow {
 	friend class NedMusicXMLImport;
 	friend class NedChangeUpbeadCommand;
 	friend class NedInstrumentTable;
+	friend class NedIdiotsEditor;
 	friend class NedChangeSpacementCommand;
 	friend class NedDeleteStaffCommand;
 };
