@@ -33,7 +33,7 @@
 #define X_PS_POS(p) ((DEFAULT_BORDER + LEFT_RIGHT_BORDER + (p)) * PS_ZOOM)
 #define Y_PS_POS_SYS_REL(p) ((page_height - ((p) + sys_y_pos)) * PS_ZOOM)
 
-NedMeasure::NedMeasure() : m_measure_number(1), m_special_descr(NULL) {
+NedMeasure::NedMeasure() : m_spread_fac(1.0), m_hide_following(false), m_measure_number(1), m_special_descr(NULL) {
 	m_measure_number_str[0] = '1';
 	m_measure_number_str[1] = '\0';
 }
@@ -41,6 +41,7 @@ NedMeasure::NedMeasure() : m_measure_number(1), m_special_descr(NULL) {
 void NedMeasure::setMeasureNumber(int num, GList *special_measures, bool force /* = false */) {
 	GList *lptr;
 
+
 	if (m_measure_number == num && !force) return;
 
 	m_special_descr = NULL;
@@ -50,6 +51,7 @@ void NedMeasure::setMeasureNumber(int num, GList *special_measures, bool force /
 		if (((SpecialMeasure *) lptr->data)->measure_number == m_measure_number) {
 			m_special_descr = (SpecialMeasure *) lptr->data;
 			//NedResource::DbgMsg(DBG_TESTING, "0x%x, type = 0x%x --> c = %d (0x%x)\n", m_special_descr, m_special_descr->type, m_measure_number, &(m_special_descr->measure)); 
+			m_hide_following = ((SpecialMeasure *) lptr->data)->hide_following;
 			m_special_descr->measure = this;
 		}
 	}
@@ -60,6 +62,11 @@ int NedMeasure::getSpecial() {
 	return m_special_descr->type;
 }
 
+bool NedMeasure::barRequiresHideFollowing() {
+	if (m_special_descr == NULL) return false;
+	return (((m_special_descr->type & REP_TYPE_MASK) == END_BAR || (m_special_descr->type & REP_TYPE_MASK) == REPEAT_CLOSE) && m_hide_following);
+}
+
 bool NedMeasure::isNearStart(double x) {
 	double dist = x - start;
 	if (dist < 0.0) dist = -dist;
@@ -74,6 +81,23 @@ bool NedMeasure::isNearStart(double x) {
 	*/
 }
 
+double NedMeasure::shiftXpos(double extra_space_divided, double shift, bool out) {
+	start += shift;
+	shift = m_position_array.shiftXpos(extra_space_divided, shift, m_measure_number, out);
+	shift += extra_space_divided;
+	return shift;
+}
+
+double NedMeasure::computeAndSetPositions(double start_position, int *num_elements, double *extra_space_for_accidentals, bool out) {
+	start_position += getNeededSpaceAfter();
+	start = start_position;
+	start_position += getNeededSpaceBefore();
+	start_position = m_position_array.computeAndSetPositions(start_position, num_elements, extra_space_for_accidentals, m_measure_number, m_spread_fac, out);
+	end = start_position;
+	return start_position;
+}
+
+
 bool NedMeasure::nearRepeatElement(double x, double y) {
 	int i = 0;
 	bool hit = false;
@@ -105,43 +129,47 @@ bool NedMeasure::isNearEnd(double x) {
 }
 
 double NedMeasure::getNeededSpaceBefore() {
-	if (m_special_descr == NULL) return MEAS_BAR_SPACE;
-	switch (m_special_descr->type & REP_TYPE_MASK) {
-		case REPEAT_OPEN: return REP_THICK_LINE_DIST;
-		case REPEAT_OPEN_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST;
-		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST;
-	}
-	return MEAS_BAR_SPACE;
-}
-double NedMeasure::getNeededSpaceAfter() {
 	if (m_special_descr == NULL) return MEAS_BAR_SPACE;
 	double timesig_offs = (m_special_descr->type & TIMESIG_TYPE_MASK) ? TIME_SIG_WIDTH : 0.0;
-
 	switch (m_special_descr->type & REP_TYPE_MASK) {
-		case REPEAT_OPEN_CLOSE: return 3 * REP_THICK_LINE_DIST + timesig_offs;
-		case REPEAT_OPEN: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + timesig_offs;
-		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + timesig_offs;
+		case REPEAT_OPEN: return REP_THICK_LINE_DIST + timesig_offs;
+		case REPEAT_OPEN_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + timesig_offs;
+		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + timesig_offs;
+		case DOUBLE_BAR: return REP_DOUBLE_LINE_DIST + timesig_offs;
 	}
 	if (m_special_descr->type & TIMESIG_TYPE_MASK) {
 		return TIME_SIG_WIDTH;
 	}
 	return MEAS_BAR_SPACE;
 }
+double NedMeasure::getNeededSpaceAfter() {
+	if (m_special_descr == NULL) return MEAS_BAR_SPACE;
+
+	switch (m_special_descr->type & REP_TYPE_MASK) {
+		case REPEAT_OPEN_CLOSE: return 3 * REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
+		case REPEAT_OPEN: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST;
+		case REPEAT_CLOSE: return REP_THICK_LINE_DIST + REP_DOTS_X_DIST + REP_DOTS_X_EXTRA_DIST;
+		case END_BAR: return 2 * REP_THICK_LINE_DIST;
+		case DOUBLE_BAR: return 3 * REP_DOUBLE_LINE_DIST;
+	}
+	return MEAS_BAR_SPACE;
+}
 
 
-void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double content_x_pos, double sys_y_pos, double top, double bottom, double bottom_ori, double leftx, double topy,
-			double staff_border_dist, double zoom_factor, int zoom_level, bool rep_line_needed) {
+void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double content_x_pos, double sys_y_pos, double top, double bottom, double bottom2, double bottom_ori, double leftx, double topy,
+			double staff_border_dist, double zoom_factor, int zoom_level, bool rep_line_needed, bool out) {
 	double line_xpos, normal_line_pos = start;
 	double repyoffs;
 	double line_bottom = bottom;
 	bool draw_default_line = true;
 	int realtype = 0;
 	double sig_xpos = start;
+
 	if (m_special_descr != NULL) {
 		realtype = m_special_descr->type & (REP_TYPE_MASK | TIMESIG_TYPE_MASK);
 	}
 
-	if (rep_line_needed) {
+	if (rep_line_needed && special_position != SPECIAL_POSITION_END) {
 		cairo_new_path(cr);
 		cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
 		repyoffs = staff_border_dist;
@@ -284,6 +312,32 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 				cairo_fill(cr);
 				draw_default_line = false;
 				break;
+			case END_BAR:
+				if (special_position == SPECIAL_POSITION_START) return;
+				line_xpos = (special_position == SPECIAL_POSITION_END) ? xpos : start;
+				cairo_new_path(cr);
+				cairo_set_line_width(cr, zoom_factor * ((special_position == SPECIAL_POSITION_END) ? REPEAT_MEASURE_LINE_THICK : MEASURE_LINE_THICK));
+				cairo_move_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(top));
+				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos - REP_THICK_LINE_DIST), Y_POS_SYS_REL(bottom2));
+				cairo_stroke(cr);
+				if (special_position != SPECIAL_POSITION_END) {
+					cairo_new_path(cr);
+					cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
+					cairo_move_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(top));
+					cairo_line_to(cr, X_POS_PAGE_REL(line_xpos), Y_POS_SYS_REL(bottom2));
+					cairo_stroke(cr);
+				}
+				draw_default_line = false;
+				break;
+			case DOUBLE_BAR:
+				if (special_position == SPECIAL_POSITION_START) return;
+				line_xpos = (special_position == SPECIAL_POSITION_END) ? xpos : start;
+				cairo_new_path(cr);
+				cairo_set_line_width(cr, zoom_factor * MEASURE_LINE_THICK);
+				cairo_move_to(cr, X_POS_PAGE_REL(line_xpos - REP_DOUBLE_LINE_DIST), Y_POS_SYS_REL(top));
+				cairo_line_to(cr, X_POS_PAGE_REL(line_xpos - REP_DOUBLE_LINE_DIST), Y_POS_SYS_REL(bottom));
+				cairo_stroke(cr);
+				break;
 			case REPEAT_OPEN_CLOSE:
 				cairo_new_path(cr);
 				cairo_set_line_width(cr, zoom_factor * REPEAT_MEASURE_LINE_THICK);
@@ -373,3 +427,8 @@ void NedMeasure::draw(cairo_t *cr, int special_position, double xpos, double con
 	cairo_stroke(cr);
 }
 
+unsigned int NedMeasure::getStoredStaffCount() {return m_position_array.getStoredStaffCount();}
+
+void NedMeasure::setNewStaffCount(int newstaffcount) {
+	m_position_array.setNewStaffCount(newstaffcount);
+}
