@@ -22,12 +22,14 @@
 #include "resource.h"
 #include "mainwindow.h"
 #include "midiexport.h"
+#include "pangocairotext.h"
 #include "note.h"
 
-#define META_TEXT    0x01
-#define META_TIMESIG 0x58
-#define META_KEYSIG  0x59
-#define META_TEMPO   0x51
+#define META_TEXT       0x01
+#define META_TRACK_NAME 0x03
+#define META_TIMESIG    0x58
+#define META_KEYSIG     0x59
+#define META_TEMPO      0x51
 
 #define MIDI_CTL_REVERB  0x5b
 #define MIDI_CTL_CHORUS  0x5d
@@ -170,6 +172,17 @@ void NedMidiExport::exportMidi(FILE *fp, NedMainWindow *main_window, char *midit
 	}
 }
 
+void NedMidiExport::writeTrackName(unsigned long long time, const char *s) {
+	const char *cptr = s;
+	if (s == NULL) return;
+	if (*s == '\0') return;
+	writeTime(time);
+	writeByte(0xff); writeByte(META_TRACK_NAME); writeByte(strlen(s));
+	while (*cptr) {
+		putc(0xff & (*cptr++), m_midiout);
+	}
+}
+
 void NedMidiExport::writeText(unsigned long long time, const char *s) {
 	const char *cptr = s;
 	writeTime(time);
@@ -335,6 +348,9 @@ void NedMidiExport::writeTrack(GList *midi_events, int track_nr, int num, int de
 	writeString(strdup("MTrk"));
 	pos0 = ftell(m_midiout);
 	writeDWord(0);
+	if (m_main_window->m_staff_contexts[track_nr].m_staff_name != NULL) {
+		writeTrackName(0, m_main_window->m_staff_contexts[track_nr].m_staff_name->getText());
+	}
 	writeTimeSig(0, m_main_window->getNumerator(), m_main_window->getDenominator());
 	writeKeySig(0, m_main_window->m_staff_contexts[track_nr].m_key_signature_number);
 	writePgmChange(0, channel, m_main_window->m_staff_contexts[track_nr].m_midi_program);
@@ -362,6 +378,21 @@ void NedMidiExport::writeTrack(GList *midi_events, int track_nr, int num, int de
 							    break;
 			}
 		}
+		for (lptr2 = (GList *) g_list_first((GList *) (lptr1->data)); lptr2; lptr2 = g_list_next(lptr2)) {
+			if (((MidiEventStruct *) lptr2->data)->channel != channel) continue;
+			switch (((MidiEventStruct *) lptr2->data)->type) {
+				case PSEUDO_EVENT_KEY_CHANGE: if (time_written) {
+									timedist = 0;
+								}
+								else {
+									timedist = MY2MIDITIME(((MidiEventStruct *) lptr2->data)->midi_time - lastEventTime);
+									time_written = TRUE;
+								}
+							      writeKeySig(timedist, ((MidiEventStruct *) lptr2->data)->data1);
+							      newlasteventtime = ((MidiEventStruct *) lptr2->data)->midi_time;
+							      break;
+			}
+		}
 		for (lptr2 = (GList *) g_list_first((GList *) (lptr1->data)); lptr2; lptr2 = g_list_next(lptr2)) {
 			if (((MidiEventStruct *) lptr2->data)->channel != channel) continue;
 			switch (((MidiEventStruct *) lptr2->data)->type) {
