@@ -19,6 +19,10 @@
 /*											*/
 /****************************************************************************************/
 
+#ifndef MIDI_IMPORTER_H
+
+#define MIDI_IMPORTER_H
+
 #include <stdio.h>
 #include <gtk/gtk.h>
 #include "importer.h"
@@ -44,3 +48,5 @@ class NedMidiImporter : public NedImporter  {
 		NedInstrumentTable *m_instrument_table;
 		int m_current_midi_instrument[16];
 };
+
+#endif /* MIDI_IMPORTER_H */
