@@ -74,7 +74,6 @@
 #define XML_TIE_TYPE_START 1
 #define XML_TIE_TYPE_STOP 2
 
-		
 
 bool NedMusicXMLImport::import() {
 #define BUFLEN 4096
@@ -89,9 +88,7 @@ bool NedMusicXMLImport::import() {
 	m_upbeat_inverse = 1;
 	m_first_measure = true;
 	m_beats = m_beat_type = 4;
-	m_current_measure_number = 0;
 
-	m_indent = 0;
 	m_semantic_error = false;
 	m_partcount = 0;
 	emtpy_state_stack();
@@ -144,15 +141,19 @@ bool NedMusicXMLImport::import() {
 
 
 void NedMusicXMLImport::produceSyntaxErrorString() {
+	char Str[DEFAULT_STRING_LENGTH - 20];
+	strncpy(Str, m_error->message, DEFAULT_STRING_LENGTH - 20 - 1);
+	Str[DEFAULT_STRING_LENGTH - 20 - 1] = '\0';
+	//sprintf(m_error_string, "line %d:%d:", line, column);
 	if (!m_semantic_error) {
-		sprintf(m_error_string, "%s (%d)", m_error->message, m_error->code);
+		sprintf(m_error_string, "%s (%d)", Str, m_error->code);
 	}
 }
 
 void NedMusicXMLImport::produceSementicErrorString(char *semantic_error) {
 	int line, column;
 	g_markup_parse_context_get_position(m_parser_context, &line, &column);
-	sprintf(m_error_string, "line %d:%d: %s", line, column, semantic_error);
+	printf("line %d:%d: %s", line, column, semantic_error);
 	m_semantic_error = true;
 }
 
@@ -198,6 +199,7 @@ int NedMusicXMLImport::pitchToLine() {
 	return line + line_offs + (m_octave_name[0] - '0' - 4) * 7 + line_add;
 }
 
+
 void NedMusicXMLImport::startTag (GMarkupParseContext *context,
                           const gchar         *element_name,
                           const gchar        **attribute_names,
@@ -376,16 +378,12 @@ void NedMusicXMLImport::startTag (GMarkupParseContext *context,
 		im->push_state(XML_STATE_MIDI_CHANNEL);
 	}
 	else if (!strcmp(element_name, "measure")) {
+		im->m_current_measure_number++;
 		im->push_state(XML_STATE_MEASURE);
 		if (!im->getAttr("number", buffer, attribute_names, attribute_values)) {
 			im->produceSementicErrorString(_("\"measure\" without \"number\""));
 			return;
 		}
-		if (sscanf(buffer, "%d", &(im->m_current_measure_number)) != 1) {
-			sprintf(Str, _("bad measure number: %s"), buffer);
-			im->produceSementicErrorString(Str);
-			return;
-		}
 	}
 	else if (!strcmp(element_name, "attributes")) {
 		im->push_state(XML_STATE_ATTRIBUTES);
@@ -403,10 +401,10 @@ void NedMusicXMLImport::startTag (GMarkupParseContext *context,
 			return;
 		}
 		if (!strcmp(buffer, "forward")) {
-			im->m_main_window->setSpecial(im->m_current_measure_number, REPEAT_OPEN);
+			im->m_main_window->setSpecial(im->m_current_measure_number, REPEAT_OPEN, false, NULL);
 		}
 		else if (!strcmp(buffer, "backward")) {
-			im->m_main_window->setSpecial(im->m_current_measure_number + 1, REPEAT_CLOSE);
+			im->m_main_window->setSpecial(im->m_current_measure_number + 1, REPEAT_CLOSE, false, NULL);
 		}
 	}
 	else if (!strcmp(element_name, "ending")) {
@@ -421,19 +419,19 @@ void NedMusicXMLImport::startTag (GMarkupParseContext *context,
 				return;
 			}
 			if (buffer[0] == '1' && buffer[1] == '\0') {
-				im->m_main_window->setSpecial(im->m_current_measure_number, REP1START);
+				im->m_main_window->setSpecial(im->m_current_measure_number, REP1START, false, NULL);
 			}
 			else if (buffer[0] == '2' && buffer[1] == '\0') {
-				im->m_main_window->setSpecial(im->m_current_measure_number, REP2START);
-				im->m_main_window->setSpecial(im->m_current_measure_number + 1, REP2END);
+				im->m_main_window->setSpecial(im->m_current_measure_number, REP2START, false, NULL);
+				im->m_main_window->setSpecial(im->m_current_measure_number + 1, REP2END, false, NULL);
 			}
 		}
 		else if (strcmp(buffer, "discontinue")) {
 			if (buffer[0] == '1' && buffer[1] == '\0') {
-				im->m_main_window->setSpecial(im->m_current_measure_number + 1, REP1END);
+				im->m_main_window->setSpecial(im->m_current_measure_number + 1, REP1END, false, NULL);
 			}
 			else if (buffer[0] == '2' && buffer[1] == '\0') {
-				im->m_main_window->setSpecial(im->m_current_measure_number + 1, REP2END);
+				im->m_main_window->setSpecial(im->m_current_measure_number + 1, REP2END, false, NULL);
 			}
 		}
 	}
@@ -537,7 +535,7 @@ void NedMusicXMLImport::endTag (GMarkupParseContext *context,
 	int line, length, dotcount;
 	unsigned int state;
 	int dummy;
-	NedChordOrRest *chord_or_rest;
+	NedChordOrRest *chord_or_rest = NULL;
 	if (im->m_semantic_error) return;
 /*
 	int i;
@@ -603,7 +601,7 @@ void NedMusicXMLImport::endTag (GMarkupParseContext *context,
 			   im->m_current_part->voices[im->m_current_voice], 
 				im->m_current_part->last_chord[im->m_current_voice] = chord_or_rest = new NedChordOrRest(NULL, TYPE_NOTE, FALSE, line, dotcount, length, NORMAL_NOTE, state, 0));
 				for (int i = 0; i < MAX_LYRICS_LINES; i++) {
-					chord_or_rest->setLyrics(i, im->m_lyrics[i]);
+					chord_or_rest->setLyricsFromOldContext(im->m_main_window, i, im->m_lyrics[i]);
 				}
 
 		}
@@ -627,6 +625,7 @@ void NedMusicXMLImport::endTag (GMarkupParseContext *context,
 		im->pop_state();
 	}
 	else if (!strcmp(element_name, "part") || !strcmp(element_name, "score-part")) {
+		im->m_current_measure_number = 0;
 		im->pop_state();
 		im->m_current_part = NULL;
 	}
@@ -1060,10 +1059,10 @@ void NedMusicXMLImport::determineClef() {
 	else if ((m_clefsign[0] == 'C' || m_clefsign[0] == 'c') && m_clefsign[1] == '\0' && m_clefline == 4) {
 		m_current_part->current_clef = TENOR_CLEF;
 	}
-	else if (!strcmp(m_clefsign, "TBD") || !strcmp(m_clefsign, "tbd") && m_clefline == 2) {
+	else if (!strcmp(m_clefsign, "TBD") || (!strcmp(m_clefsign, "tbd") && m_clefline == 2)) {
 		m_current_part->current_clef = NEUTRAL_CLEF2;
 	}
-	else if (!strcmp(m_clefsign, "TBD") || !strcmp(m_clefsign, "tbd") && m_clefline == 4) {
+	else if (!strcmp(m_clefsign, "TBD") || (!strcmp(m_clefsign, "tbd") && m_clefline == 4)) {
 		m_current_part->current_clef = NEUTRAL_CLEF1;
 	}
 	else {
@@ -1227,7 +1226,7 @@ void NedMusicXMLImport::determineGrace(int *length, char *type, bool splash) {
 }
 
 void NedMusicXMLImport::determineUpBeat() {
-	unsigned long long measure_length, voice_duration = 0;
+	unsigned long long measure_length = 0, voice_duration = 0;
 	GList *lptr;
 
 	switch (m_beat_type) {
