@@ -370,6 +370,7 @@ void NedNote::correctTieForward() {
 }
 
 void NedNote::setOffset(char offs_array[OFFS_ARRAY_SIZE]) {
+	if (offs_array[m_line + OFFS_ARRAY_HALF] != 0) return;
 	switch (m_status & ACCIDENTAL_MASK) {
 		case STAT_DFLAT: offs_array[m_line + OFFS_ARRAY_HALF] = -2;
 				break;
@@ -475,7 +476,7 @@ int NedNote::getPitch(int clef, int keysig, int octave_shift, int pitch_offs, bo
 	p = lineToPitch[m_line+offs].pitch; 
 	memset(offs_array, 0, sizeof(offs_array));
 	//getStaff()->findAccidentals(offs_array, getSystem()->getMeasure(m_chord_or_rest->getMidiTime()), m_chord_or_rest->getMidiTime());
-	getStaff()->findAccidentals(offs_array, m_chord_or_rest->m_measure, m_chord_or_rest->getMidiTime());
+	getStaff()->findAccidentals(offs_array, m_chord_or_rest->m_measure, m_chord_or_rest->getMidiTime(), true);
 	
 	switch (m_status & ACCIDENTAL_MASK) {
 		case STAT_DFLAT: p -= 2; *flat = true;
@@ -526,7 +527,7 @@ void NedNote::removeUnneededAccidental(int clef, int keysig, int octave_shift) {
 	}
 	p = lineToPitch[m_line+offs].pitch + octave_shift; 
 	memset(offs_array, 0, sizeof(offs_array));
-	getStaff()->findAccidentals(offs_array, m_chord_or_rest->m_measure, m_chord_or_rest->getMidiTime());
+	getStaff()->findAccidentals(offs_array, m_chord_or_rest->m_measure, m_chord_or_rest->getMidiTime(), false);
 	switch (m_status & ACCIDENTAL_MASK) {
 		case STAT_FLAT: if (offs_array[m_line+OFFS_ARRAY_HALF] == -1) {
 					 m_status &= (~(ACCIDENTAL_MASK));
