@@ -76,7 +76,7 @@ m_width(width), m_height(height), default_border(DEFAULT_BORDER), m_page_number(
 		m_system_diff = 100.0;
 		m_systems = g_list_append(m_systems, system = new NedSystem(this, system_pos,
 			m_width - 2 * (LEFT_RIGHT_BORDER - DEFAULT_BORDER), i, start_measure_number, TRUE));
-		placeStaffs(true, 0);
+		placeStaffs(0);
 		/*
 		do {
 			m_systems = g_list_append(m_systems, system = new NedSystem(this, system_pos,
@@ -544,11 +544,11 @@ void NedPage::removeUnneededAccidentals() {
 }
 
 
-void NedPage::prepareReplay() {
+void NedPage::prepareReplay(bool with_keysig /* = false */) {
 	GList *lptr;
 
 	for (lptr = g_list_first(m_systems); lptr; lptr = g_list_next(lptr)) {
-		((NedSystem *) lptr->data)->prepareReplay();
+		((NedSystem *) lptr->data)->prepareReplay(with_keysig);
 		NedResource::increaseSystemStartTime(((NedSystem *) lptr->data)->getSystemEndTime());
 
 	}
@@ -1052,6 +1052,9 @@ bool NedPage::findLine(double x, double y, double *ypos, int *line, double *bott
 	GList *lptr;
 	double mindist, d;
 	lptr = g_list_first(m_systems);
+	if (lptr == NULL) {
+		return FALSE; // don't know in which case this happens; concerns mainly MIDI import
+	}
 	NedSystem *nearest_system = (NedSystem *) lptr->data;
 	mindist = nearest_system->computeMidDist(y);
 	for (lptr = g_list_next(lptr); lptr; lptr = g_list_next(lptr)) {
@@ -1143,6 +1146,7 @@ NedPage *NedPage::getPreviousPage() {
 }
 
 
+
 bool NedPage::placeStaffs(int pass, NedCommandList *command_list /* = NULL */) {
 	GList *lptr;
 	NedPage *other_page;
@@ -1227,6 +1231,7 @@ NedSystem *NedPage::getNextSystem(NedSystem *system, NedCommandList *command_lis
 	if (isEmpty()) return NULL;
 
 	if ((lptr = g_list_find(m_systems, system)) == NULL) {
+		printf("gesucht war: 0x%x\n", system); fflush(stdout);
 		NedResource::Abort("NedPage::getNextSystem");
 	}
 
