@@ -34,6 +34,10 @@ NedPosition::NedPosition(NedChordOrRest *element, int offs, unsigned int staff_c
 	m_voice_members.setLen(VOICE_COUNT * staff_count, true);
 	m_staff_members.setLen(staff_count, true);
 	m_count_of_elements_per_staff.setLen(staff_count, true);
+	if (element->getType() == TYPE_KEYSIG) {
+		return; // TODO: this shouldn't happen (???)
+		NedResource::Abort("TYPE_KEYSIG(1)");
+	}
 	if ((element->getType() & (TYPE_NOTE | TYPE_REST)) != 0) {
 		m_voice_members.insert(offs, element);
 		m_has_only_staff_members = false;
@@ -62,6 +66,9 @@ void NedPosition::insertElement(NedChordOrRest *element, int offs) {
 	m_midi_time = element->getMidiTime();
 	m_valid = true;
 	m_has_only_staff_members = false;
+	if (element->getType() == TYPE_KEYSIG) {
+		NedResource::Abort("TYPE_KEYSIG(2)");
+	}
 
 	if (element->getType() == TYPE_NOTE) {
 		m_has_notes = true;
@@ -93,9 +100,11 @@ void NedPosition::insertElement(NedChordOrRest *element, int offs) {
 
 bool NedPosition::insertStaffElement(NedChordOrRest *element, int staff_offs) {
 	unsigned int c;
+	/*
 	if (m_valid) {
 		if (m_staff_members.getAt(staff_offs) != NULL) return false;
 	}
+	*/
 	m_has_only_graces = false;
 	m_midi_time = element->getMidiTime();
 	m_valid = true;
