@@ -269,6 +269,10 @@
 #define STAT_ARPEGGIO (1 << 19)
 #define STAT_BREAK_BEAM (1 << 20)
 #define STAT_FORCE_BEAM (1 << 21)
+#define CHORD_STAT_MASK (STAT_STACC  | STAT_PIZZ      | STAT_TENUTO    | \
+                         STAT_SFORZATO  | STAT_SFORZANDO | STAT_BOW_UP    | STAT_BOW_DOWN  | \
+                         STAT_PED_ON    | STAT_PED_OFF   | STAT_TRILL     | STAT_PRALL     | \
+                         STAT_MORDENT   | STAT_OPEN      | STAT_STACCATISSIMO | STAT_FERMATA | STAT_ARPEGGIO )
 #define STAT_USER_STEMDIR (1 << 22)
 #define STAT_USER_HIDDEN_REST  (1 << 23)
 #define STAT_USER_PLACED_REST  (1 << 24)
@@ -392,6 +396,12 @@
 #define OFFS_ARRAY_SIZE 115
 #define OFFS_ARRAY_HALF (OFFS_ARRAY_SIZE / 2)
 
+#define X11_ICONS_DIM 25
+#define X11_ICONS_BACK_DIM 35
+
+#define X11_MINI_ICONS_DIM 20
+#define X11_ICONS_BACK_MINI_DIM 25
+
 #define DBG_NO 0
 #define DBG_TESTING 1
 #define DBG_CRITICAL 2
@@ -413,6 +423,7 @@ class NedMainWindow;
 class NedSystem;
 class NedPage;
 class NedMeasure;
+class NedTools;
 
 
 struct MidiPortStruct;
@@ -437,6 +448,7 @@ struct MidiEventStruct {
 #define NOTE_MASK (0xffff)
 #define PSEUDO_EVENT_MEASURE (PSEUDO_FLAG | 0x1)
 #define PSEUDO_EVENT_TEMPO_CHANGE (PSEUDO2_FLAG | 0x2)
+#define PSEUDO_EVENT_KEY_CHANGE (PSEUDO2_FLAG | 0x4)
 	int data1, data2;
 	NedNote *note;
 	NedMeasure *measure;
@@ -506,6 +518,8 @@ class NedResource {
 
 		static GdkPixbuf *m_arrow_up_icon;
 		static GdkPixbuf *m_arrow_down_icon;
+		static GdkPixbuf *m_arrow_left_icon;
+		static GdkPixbuf *m_arrow_right_icon;
 
 		static GdkPixbuf *m_treble_clef_icon;
 		static GdkPixbuf *m_bass_clef_icon;
@@ -518,6 +532,7 @@ class NedResource {
 
 		static GdkPixbuf *m_lyrics_icon;
 		static GdkPixbuf *m_key_icon;
+		static GdkPixbuf *m_tool_icon;
 
 		static GdkPixbuf *m_normal_note_icon;
 		static GdkPixbuf *m_drum1_icon;
@@ -566,7 +581,13 @@ class NedResource {
 		static int m_signs_buf_width, m_signs_buf_height;
 
 		static GdkPixbuf *m_background1;
+		static GdkPixbuf *m_mini_background1;
+		static GdkPixbuf *m_mini_background2;
 		static GdkPixbuf *m_background2;
+		static GdkPixbuf *m_backgroundv1;
+		static GdkPixbuf *m_backgroundv2;
+		static GdkPixbuf *m_backgroundh1;
+		static GdkPixbuf *m_backgroundh2;
 
 
 		static NedBbox m_acc_bbox;
@@ -597,6 +618,7 @@ class NedResource {
 			unsigned short segno_sign, NedNote *note);
 		static void addMidiCtrlEvent(unsigned short channel, unsigned int offset, unsigned int ctrl_param, int val);
 		static void addTempoChange(unsigned int offset, double tempoinverse);
+		static void addKeysigEntry(unsigned int offset, int chn, int key);
 		static void addTempoChangeAbs(unsigned long long midi_time, double tempoinverse);
 		static void addMeasureEntry(NedMeasure *measure);
 		static void addTempoChange(double tempoinverse);
@@ -625,6 +647,7 @@ class NedResource {
 		static char *m_recent_files[MAX_RECENT_FILES];
 		static void addToRecentFiles(char *fname);
 		static int getClefDist(int oldclef, int old_oct_offs, int newclef, int new_oct_offs);
+		static void reset_tools();
 		static void playImmediately(int channel, int pgm, int pitch, int vol);
 		static bool alsaSequencerOk() {return m_sequ != NULL;}
 		static bool m_avoid_immadiate_play;
@@ -638,7 +661,7 @@ class NedResource {
 #ifdef YELP_PATH
 		static char *m_yelparg;
 #endif
-		static GList *m_main_windows;
+		static GList *m_main_windows, *m_window_with_last_focus;
 		static void appendTempFileName(char *fname);
 		static const char *m_last_folder;
 		static char *m_last_xml_dir;
@@ -660,6 +683,27 @@ class NedResource {
 		static const char *getLilyPondClefName(int clef_number);
 		static const char *getLilyPondKeySigName(int keysig_number);
 		static void makeLilyString(char *ori, char *buffer);
+		static unsigned int getCurrentLength();
+		static int getCurrentNoteHead();
+		static unsigned int getStatus();
+		static bool getRestMode();
+		static int getDotCount();
+		static bool getTiedMode();
+		static void setButtons(unsigned int length, int dotcount, unsigned int chord_status, unsigned int note_status, bool isRest, bool tie_forward, int note_head);
+		static void setNoteLengthButtons(unsigned int length);
+		static void setToolboxTransient(NedMainWindow *w);
+		static void popup_tools(NedMainWindow *w);
+		static void resetSomeButtons();
+		static void resetButtons();
+		static void toggleButton(int nr);
+		static void toggleRest();
+		static void toggleTie();
+		static void toggleDot();
+		static void toggleSharp();
+		static void toggleNatural();
+		static void toggleFlat();
+		static NedMainWindow *getMainwWindowWithLastFocus();
+		static void setMainwWindowWithFocus(NedMainWindow *w);
 	private:
 		static void printMidiEvent(MidiEventStruct *ev);
 		static void removeAllPseudosEvents();
@@ -707,6 +751,7 @@ class NedResource {
 		static void loadPixmap(const guint8 *data, GdkPixbuf **pixbuf, const char *stock_id, int *width, int *height);
 		static GtkIconFactory *m_icon_factory;
 		static struct timeval m_expected_time;
+		static NedTools *m_tools;
 		static double m_flag_width;
 		static char m_word_buffer[128];
 		static snd_seq_t *m_sequ;
