@@ -134,6 +134,10 @@ void NedStaff::setAndUpdateClefTypeAndKeySig(int *clef_and_key_array, bool first
 	int k;
 	for (lptr = g_list_first(m_staffelems); lptr; lptr = g_list_next(lptr)) {
 		if (((NedChordOrRest *) lptr->data)->getType() == TYPE_CLEF) {
+			if (((NedChordOrRest *) lptr->data)->getMidiTime() == 0) {
+				m_clef_type = ((NedChordOrRest *) lptr->data)->getLength();
+				m_clef_octave_shift = ((NedChordOrRest *) lptr->data)->getDotCount();
+			}
 			clef_and_key_array[3 * m_staff_number + 0] = ((NedChordOrRest *) lptr->data)->getLength(); // clef number
 			clef_and_key_array[3 * m_staff_number + 1] = ((NedChordOrRest *) lptr->data)->getDotCount(); // octave shift
 		}
@@ -484,6 +488,7 @@ void NedStaff::draw(cairo_t *cr, double botpos, double botpos2, bool first_page,
 		getSystem()->getMeasureNr(i)->draw(cr, (i == mcount) ? SPECIAL_POSITION_END : SPECIAL_POSITION_NONE, m_width, getPage()->getContentXpos(),  getSystem()->getYPos(), m_ypos, botpos, botpos2, getBottomPos(), leftx, topy, m_top_y_border, zoom_factor, zoom_level, rep_line_needed, getSystem()->getSystemNumber() == 4);
 	}
 	for (lptr = g_list_first(m_staffelems); lptr; lptr = g_list_next(lptr)) {
+		if (((NedChordOrRest *) lptr->data)->getMidiTime() == 0 && ((NedChordOrRest *) lptr->data)->getType() == TYPE_CLEF) continue;
 		((NedChordOrRest *) lptr->data)->draw(cr, &dummy);
 	}
 	if (getMainWindow()->m_staff_contexts[m_staff_number].m_staff_name != NULL ||
@@ -862,13 +867,16 @@ void NedStaff::deleteStaffElements(bool unexecute, GList *elems, unsigned long l
 			NedResource::Abort("NedStaff::deleteStaffElements");
 		}
 		if (!unexecute) {
-			//measure = m_system->getMeasure(((NedChordOrRest *) lptr2->data)->getMidiTime());
+		/*
+			measure = m_system->getMeasure(((NedChordOrRest *) lptr2->data)->getMidiTime());
 			measure = ((NedChordOrRest *) lptr2->data)->m_measure;
 			if (measure == NULL) {
 				NedResource::DbgMsg(DBG_TESTING, "measure = 0 fuer time %llu (%llu)\n", ((NedChordOrRest *) lptr2->data)->getMidiTime(),
 					((NedChordOrRest *) lptr2->data)->getMidiTime() / NOTE_4); 
 			}
 			((NedChordOrRest *) lptr2->data)->decrMidiTime(measure->midi_start);
+			*/
+			((NedChordOrRest *) lptr2->data)->decrMidiTime(reftime);
 		}
 		m_staffelems = g_list_delete_link(m_staffelems, lptr2);
 	}
@@ -978,7 +986,7 @@ int NedStaff::computeVolume(unsigned long long midi_time) {
 	return volume;
 }
 
-void NedStaff::prepareReplay() {
+void NedStaff::prepareReplay(bool with_keysig) {
 	int i;
 	GList *lptr;
 
@@ -992,6 +1000,15 @@ void NedStaff::prepareReplay() {
 		m_voices[i]->prepareReplay();
 	}
 
+	if (with_keysig) {
+		for (lptr = g_list_first(m_staffelems); lptr; lptr = g_list_next(lptr)) {
+			if ((((NedChordOrRest *) lptr->data)->getType() & TYPE_KEYSIG) == 0) continue;
+			NedResource::addKeysigEntry(((NedChordOrRest *) lptr->data)->getMidiTime(), 
+				getMainWindow()->m_staff_contexts[m_staff_number].m_midi_channel,
+				((NedChordOrRest *) lptr->data)->getLength() /* keysig */);
+		}
+	}
+
 	if (m_volume_changes != NULL) {
 		if ((lptr = g_list_last(m_volume_changes)) != NULL) {
 			getMainWindow()->m_staff_contexts[m_staff_number].m_current_midi_volume =
@@ -1006,11 +1023,11 @@ void NedStaff::prepareReplay() {
 	}
 }
 
-void NedStaff::findAccidentals(char offs_array[115], NedMeasure *meas_info, unsigned long long  midi_time) {
+void NedStaff::findAccidentals(char offs_array[115], NedMeasure *meas_info, unsigned long long  midi_time, bool including) {
 	int i;
 
 	for (i = 0; i < VOICE_COUNT; i++) {
-		m_voices[i]->findAccidentals(offs_array, meas_info, midi_time);
+		m_voices[i]->findAccidentals(offs_array, meas_info, midi_time, including);
 	}
 }
 
@@ -1121,6 +1138,7 @@ int NedStaff::assignElementsToMeasures(NedMeasure *measures, int staff_offs, boo
 			curr_measure++;
 		}
 		if (((NedChordOrRest *) lptr->data)->getMidiTime() > measures[curr_measure].midi_end) continue;
+		if (((NedChordOrRest *) lptr->data)->getMidiTime() == 0 && ((NedChordOrRest *) lptr->data)->getType() == TYPE_CLEF) continue;
 		measures[curr_measure].m_position_array.insertStaffElement(
 			(NedChordOrRest *) lptr->data, staff_offs / VOICE_COUNT, measures[curr_measure].getMeasureNumber());
 		((NedChordOrRest *) lptr->data)->m_measure = &(measures[curr_measure]);
