@@ -98,8 +98,8 @@ class NedStaff {
 		void saveStaff(FILE *fp);
 		void restoreStaff(FILE *fp);
 		int computeVolume(unsigned long long midi_time);
-		void prepareReplay();
-		void findAccidentals(char offs_array[115], NedMeasure *meas_info, unsigned long long midi_time);
+		void prepareReplay(bool with_keysig);
+		void findAccidentals(char offs_array[115], NedMeasure *meas_info, unsigned long long midi_time, bool including);
 		void setInternalPitches();
 		void adjustAccidentals();
 		void transpose(int pitchdist, GList *selected_group);
