@@ -825,7 +825,7 @@ bool NedSystem::reposit(int measure_number, NedCommandList *command_list /* = NU
 		//printf("pag: %d sys: %d: m_extra_space(%f) < MINIMUM_EXTRA_SPACE (%f)reposit\n", m_page->getPageNumber(), m_system_number, m_extra_space, MINIMUM_EXTRA_SPACE); fflush(stdout);
 		m_check_line_compression = FALSE;
 		NedClipBoard *board = new NedClipBoard();
-		board->setRefTimeAndDuration(m_measures[m_measure_count-2].midi_start, m_measures[m_measure_count-1].midi_end - m_measures[m_measure_count-1].midi_start);
+		board->setRefTimeAndDuration(m_measures[m_measure_count-1].midi_start, m_measures[m_measure_count-1].midi_end - m_measures[m_measure_count-1].midi_start);
 		for (lptr = g_list_first(m_staffs); lptr; lptr = g_list_next(lptr)) {
 			((NedStaff *) lptr->data)->collectChordsAndRests(board, m_measures[m_measure_count-1].midi_start,  m_measures[m_measure_count-1].midi_end);
 		}
@@ -841,7 +841,7 @@ bool NedSystem::reposit(int measure_number, NedCommandList *command_list /* = NU
 		newnum = m_measures[m_measure_count-1].getMeasureNumber();
 		if (other_system != NULL) {
 			other_system->collectDestinationVoices(board);
-			command_list->addSystemForRepositioning(other_system);
+			// Do not add this because if unexecute the syszem is already deleted command_list->addSystemForRepositioning(other_system);
 			compute_extra_space(use_upbeat);
 			//do_reposit(use_upbeat);
 			newnum = m_measures[m_measure_count-1].getMeasureNumber() + 1;
@@ -859,7 +859,7 @@ bool NedSystem::reposit(int measure_number, NedCommandList *command_list /* = NU
 		//printf("pag: %d sys: %d : m_extra_space(%f) > MAXIMUM_EXTRA_SPACE (%f)reposit\n", m_page->getPageNumber(), m_system_number, m_extra_space, MAXIMUM_EXTRA_SPACE); fflush(stdout);
 		if ((other_system = m_page->getNextSystem(this)) != NULL) {
 			NedClipBoard *board = new NedClipBoard();
-			if (other_system->collectFirstMeasure(board)) {
+			if (other_system->collectFirstMeasure(board, getSystemEndTime())) {
 				collectDestinationVoices(board);
 				if (board->onlyWholeRests() && m_page->isLastSystem(this)) {
 					board->setInsertOnly();
@@ -970,10 +970,10 @@ double NedSystem::placeStaffs(double staffpos) {
 	return yy + m_ypos + SYSTEM_MIN_DIST;
 }
 
-bool NedSystem::collectFirstMeasure(NedClipBoard *board) {
+bool NedSystem::collectFirstMeasure(NedClipBoard *board, unsigned long long length_of_previous_system) {
 	GList *lptr;
 	if (m_measure_count < 2) return FALSE;
-	board->setRefTimeAndDuration(m_measures[0].midi_start, m_measures[0].midi_end);
+	board->setRefTimeAndDuration(length_of_previous_system, m_measures[0].midi_end);
 	for (lptr = g_list_first(m_staffs); lptr; lptr = g_list_next(lptr)) {
 		((NedStaff *) lptr->data)->collectChordsAndRests(board, m_measures[0].midi_start,  m_measures[0].midi_end);
 	}
@@ -1384,12 +1384,12 @@ int NedSystem::getNumberOfStaffs() {
 }
 
 
-void NedSystem::prepareReplay() {
+void NedSystem::prepareReplay(bool with_keysig) {
 	GList *lptr;
 
 	for (lptr = g_list_first(m_staffs); lptr; lptr = g_list_next(lptr)) {
 		if (getMainWindow()->m_staff_contexts[((NedStaff *) lptr->data)->getStaffNumber()].m_muted) continue;
-		((NedStaff *) lptr->data)->prepareReplay();
+		((NedStaff *) lptr->data)->prepareReplay(with_keysig);
 	}
 }
 
