@@ -28,7 +28,7 @@
 #include "staff.h"
 #include "beam.h"
 
-#define X_POS_PAGE_REL(p) ((getPage()->getContetXpos() + (p)) * zoom_factor - leftx)
+#define X_POS_PAGE_REL(p) ((getPage()->getContentXpos() + (p)) * zoom_factor - leftx)
 #define Y_POS_STAFF_REL(p) (((p) + getSystem()->getYPos() + getStaff()->getBottomPos()) * zoom_factor - topy)
 #define Y_POS_SYS_REL(p) (((p) + getSystem()->getYPos()) * zoom_factor - topy)
 
@@ -141,7 +141,7 @@ void NedTuplet::reconfigureLast() {
 	GList *lptr, *maxmidichordorrest;
 	unsigned int maxmiditime;
 
-	((NedChordOrRest *) g_list_first(m_chords)->data)->getVoice()->resetPositionPointer(FALSE); //recompute MIDI Times
+	((NedChordOrRest *) g_list_first(m_chords)->data)->getVoice()->assignMidiTimes(); //recompute MIDI Times
 	maxmidichordorrest = lptr = g_list_first(m_chords);
 	maxmiditime = ((NedChordOrRest *) lptr->data)->getMidiTime();
 	for (lptr = g_list_next(lptr); lptr; lptr = g_list_next(lptr)) {
