@@ -50,6 +50,17 @@ void NedVolumeSign::setMidiVolume() {
 	}
 }
 
+int NedVolumeSign::determineKind(int volume) {
+	if (volume <= 18) return VOL_PPP;
+	if (volume <= 36) return VOL_PP;
+	if (volume <= 54) return VOL_P;
+	if (volume <= 72) return VOL_MF;
+	if (volume <= 91) return VOL_F;
+	if (volume <= 108) return VOL_FF;
+	return VOL_FFF;
+}
+	
+
 NedFreeReplaceable *NedVolumeSign::clone(struct addr_ref_str **slurlist, NedChordOrRest *newelement, GtkWidget *drawing_area /* = NULL */, 
 	NedMainWindow *main_window /* = NULL */) {
 	NedVolumeSign *newVolSig = new NedVolumeSign(m_kind, newelement, m_x, m_y, true);
